<?php

class LoginService {
    function login(LoginVO $data) {
        
        if(Zend_Auth::getInstance()->hasIdentity()){
            Zend_Auth::getInstance()->clearIdentity();
        }
        
        Zend_Loader::loadClass("DbTable", APPLICATION_PATH.'/controllers/amf');
        $authAdapter = new DbTable(Zend_Db_Table::getDefaultAdapter());
        $authAdapter->setTableName('users')
                        ->setIdentityColumn('username')
                        ->setCredentialColumn('password');
        
        $username = htmlspecialchars($data->username);
        
        if(preg_match("/^([a-zA-Z0-9])+([a-zA-Z0-9\._-])*@([a-zA-Z0-9_-])+([a-zA-Z0-9\._-]+)+$/", $username)){
            $username = strstr($username, '@', true);
        }
        
        $authAdapter->setIdentity($username)
                    ->setCredential(htmlspecialchars($data->signature));

        $auth = Zend_Auth::getInstance();
        $result = $auth->authenticate($authAdapter);
    
        if($result->isValid()){
            $userInfo = $authAdapter->getResultRowObject(null, 'password');
            
            if($userInfo->role !== 'Administrator'){
                $this->logoutService();
                throw new Zend_Amf_Exception("LoginService.AUTHORISATION_FAIL.You are not permitted");
            }

            $authStorage = $auth->getStorage();
            $authStorage->write($userInfo);

            $userVO = new UserVO();
            $userVO->id = $userInfo->id;
            $userVO->email = $userInfo->email;
            $userVO->role = $userInfo->role;
    
            return $userVO;
        }else{
            throw new Zend_Amf_Exception("LoginService.AUTHORISATION_FAIL.You are not authorised");
        }
    }
    
    function isLogged(){
        return Zend_Auth::getInstance()->hasIdentity();
    }
    
    function getToken(){
        $_SESSION['challenge'] = uniqid(rand()+time(),true);
        return $_SESSION['challenge'];
    }

    function logoutService(){
        $auth = Zend_Auth::getInstance();

        if($auth->hasIdentity()){
            $auth->clearIdentity();
            
            return true;
        }else{
            return false;
        }
    }
}
?>
